<h2 align="center">
<img src="https://github.com/GLEF1X/glQiwiApi/blob/dev-2.x/docs/_static/logo.png?raw=true" width="200"></img>


[![PyPI version](https://img.shields.io/pypi/v/glQiwiApi.svg)](https://pypi.org/project/glQiwiApi/) [![Code Quality Score](https://api.codiga.io/project/20780/score/svg)](https://frontend.code-inspector.com/public/project/20780/glQiwiApi/dashboard) ![Downloads](https://img.shields.io/pypi/dm/glQiwiApi) ![docs](https://readthedocs.org/projects/pip/badge/?version=latest)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/GLEF1X/glQiwiApi.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/GLEF1X/glQiwiApi/context:python) [![CodeFactor](https://www.codefactor.io/repository/github/glef1x/glqiwiapi/badge)](https://www.codefactor.io/repository/github/glef1x/glqiwiapi)
![codecov](https://codecov.io/gh/GLEF1X/glQiwiApi/branch/dev-2.x/graph/badge.svg?token=OD538HKV15)
![CI](https://github.com/GLEF1X/glQiwiApi/actions/workflows/tests.yml/badge.svg) ![mypy](https://img.shields.io/badge/%20type_checker-mypy-%231674b1?style=flat) [![Downloads](https://pepy.tech/badge/glqiwiapi/month)](https://pepy.tech/project/glqiwiapi) [![Downloads](https://pepy.tech/badge/glqiwiapi)](https://pepy.tech/project/glqiwiapi)

<img src="https://github.com/GLEF1X/glQiwiApi/blob/dev-2.x/docs/static/demo.gif"/>
</h2>

## 🌎Official api resources:

* 🎓 __Documentation: [here](https://glqiwiapi.readthedocs.io/en/latest/)__
* 🖱️ __Telegram chat: [![Dev-Telegram](https://img.shields.io/badge/Telegram-blue.svg?style=flat-square&logo=telegram)](https://t.me/glQiwiAPIOfficial)__

## Benchmarks

```bash
hint: smaller is better
glQiwiApi      90.9925 (1.0)      103.3993 (1.0)       95.4082 (1.0)      5.3941 (1.0)       92.4023 (1.0)       8.2798 (1.0)
pyQiwiP2P     112.2819 (1.23)     135.0227 (1.31)     123.7498 (1.30)     9.9919 (1.85)     127.5926 (1.38)     17.2723 (2.09)
```

## 🐦Dependencies

| Library |                       Description                       |
|:-------:|:-------------------------------------------------------:|
|aiohttp  | Asynchronous HTTP Client/Server for asyncio and Python. |
|pydantic |    Json data validator. Very fast instead of custom     |
